@@ -7,98 +7,6 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
-class LinearSvmModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LinearSvmModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class LinearSvmPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LinearSvmPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class LinearSvmTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LinearSvmTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setL1(self, val):
-        return self._add_param('l1', val)
-
-    def setL2(self, val):
-        return self._add_param('l2', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setOptimMethod(self, val):
-        return self._add_param('optimMethod', val)
-
-    def setStandardization(self, val):
-        return self._add_param('standardization', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-
-class LogisticRegressionModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LogisticRegressionModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LogisticRegressionModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
 class LogisticRegressionPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LogisticRegressionPredictBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -112,6 +20,15 @@ class LogisticRegressionPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -188,6 +105,15 @@ class LookupBatchOp(BatchOperator):
     def setMapValueCols(self, val):
         return self._add_param('mapValueCols', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setModelStreamUpdateMethod(self, val):
         return self._add_param('modelStreamUpdateMethod', val)
 
@@ -201,38 +127,6 @@ class LookupBatchOp(BatchOperator):
         return self._add_param('reservedCols', val)
 
 
-class LookupRedisBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.LookupRedisBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LookupRedisBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputSchemaStr(self, val):
-        return self._add_param('outputSchemaStr', val)
-
-    def setPluginVersion(self, val):
-        return self._add_param('pluginVersion', val)
-
-    def setRedisIP(self, val):
-        return self._add_param('redisIP', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setRedisPassword(self, val):
-        return self._add_param('redisPassword', val)
-
-    def setRedisPort(self, val):
-        return self._add_param('redisPort', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
 class LookupValueInTimeSeriesBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.LookupValueInTimeSeriesBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -317,6 +211,15 @@ class MaxAbsScalerPredictBatchOp(BatchOperator):
         super(MaxAbsScalerPredictBatchOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -338,71 +241,6 @@ class MaxAbsScalerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
         return self._add_param('selectedCols', val)
 
 
-class MetaPath2VecBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.graph.MetaPath2VecBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MetaPath2VecBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMetaPath(self, val):
-        return self._add_param('metaPath', val)
-
-    def setSourceCol(self, val):
-        return self._add_param('sourceCol', val)
-
-    def setTargetCol(self, val):
-        return self._add_param('targetCol', val)
-
-    def setTypeCol(self, val):
-        return self._add_param('typeCol', val)
-
-    def setVertexCol(self, val):
-        return self._add_param('vertexCol', val)
-
-    def setWalkLength(self, val):
-        return self._add_param('walkLength', val)
-
-    def setWalkNum(self, val):
-        return self._add_param('walkNum', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setBatchSize(self, val):
-        return self._add_param('batchSize', val)
-
-    def setIsToUndigraph(self, val):
-        return self._add_param('isToUndigraph', val)
-
-    def setMinCount(self, val):
-        return self._add_param('minCount', val)
-
-    def setMode(self, val):
-        return self._add_param('mode', val)
-
-    def setNegative(self, val):
-        return self._add_param('negative', val)
-
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setRandomWindow(self, val):
-        return self._add_param('randomWindow', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setWindow(self, val):
-        return self._add_param('window', val)
-
-
 class MetaPathWalkBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.graph.MetaPathWalkBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -440,9 +278,6 @@ class MetaPathWalkBatchOp(BatchOperator):
     def setIsToUndigraph(self, val):
         return self._add_param('isToUndigraph', val)
 
-    def setSamplingMethod(self, val):
-        return self._add_param('samplingMethod', val)
-
     def setWeightCol(self, val):
         return self._add_param('weightCol', val)
 
@@ -468,6 +303,15 @@ class MinMaxScalerPredictBatchOp(BatchOperator):
         super(MinMaxScalerPredictBatchOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -550,6 +394,15 @@ class MultiHotPredictBatchOp(BatchOperator):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -596,6 +449,15 @@ class MultiStringIndexerPredictBatchOp(BatchOperator):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -636,6 +498,15 @@ class MultilayerPerceptronPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -740,6 +611,15 @@ class NaiveBayesPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -777,6 +657,15 @@ class NaiveBayesTextPredictBatchOp(BatchOperator):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -853,68 +742,6 @@ class NegativeItemSamplingBatchOp(BatchOperator):
         return self._add_param('samplingFactor', val)
 
 
-class Node2VecBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.graph.Node2VecBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Node2VecBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSourceCol(self, val):
-        return self._add_param('sourceCol', val)
-
-    def setTargetCol(self, val):
-        return self._add_param('targetCol', val)
-
-    def setWalkLength(self, val):
-        return self._add_param('walkLength', val)
-
-    def setWalkNum(self, val):
-        return self._add_param('walkNum', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setBatchSize(self, val):
-        return self._add_param('batchSize', val)
-
-    def setIsToUndigraph(self, val):
-        return self._add_param('isToUndigraph', val)
-
-    def setMinCount(self, val):
-        return self._add_param('minCount', val)
-
-    def setNegative(self, val):
-        return self._add_param('negative', val)
-
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setP(self, val):
-        return self._add_param('p', val)
-
-    def setQ(self, val):
-        return self._add_param('q', val)
-
-    def setRandomWindow(self, val):
-        return self._add_param('randomWindow', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setWindow(self, val):
-        return self._add_param('window', val)
-
-    def setWordDelimiter(self, val):
-        return self._add_param('wordDelimiter', val)
-
-
 class Node2VecWalkBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.graph.Node2VecWalkBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -949,9 +776,6 @@ class Node2VecWalkBatchOp(BatchOperator):
     def setQ(self, val):
         return self._add_param('q', val)
 
-    def setSamplingMethod(self, val):
-        return self._add_param('samplingMethod', val)
-
     def setWeightCol(self, val):
         return self._add_param('weightCol', val)
 
@@ -1015,6 +839,15 @@ class OneHotPredictBatchOp(BatchOperator):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1118,6 +951,15 @@ class PcaPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1201,3 +1043,194 @@ class PrintBatchOp(BaseSinkBatchOp):
         super(PrintBatchOp, self).__init__(*args, **kwargs)
         pass
 
+
+class ProphetBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ProphetBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ProphetBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setStanInit(self, val):
+        return self._add_param('stanInit', val)
+
+    def setUncertaintySamples(self, val):
+        return self._add_param('uncertaintySamples', val)
+
+
+class ProphetPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ProphetPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ProphetPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class ProphetTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ProphetTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ProphetTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+
+class PyBinaryScalarFunctionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryScalarFunctionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PyBinaryScalarFunctionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClassObject(self, val):
+        return self._add_param('classObject', val)
+
+    def setClassObjectType(self, val):
+        return self._add_param('classObjectType', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setResultType(self, val):
+        return self._add_param('resultType', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class PyBinaryTableFunctionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryTableFunctionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PyBinaryTableFunctionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClassObject(self, val):
+        return self._add_param('classObject', val)
+
+    def setClassObjectType(self, val):
+        return self._add_param('classObjectType', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setResultTypes(self, val):
+        return self._add_param('resultTypes', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class QuantileDiscretizerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.feature.QuantileDiscretizerModelInfoBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(QuantileDiscretizerModelInfoBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
+class QuantileDiscretizerPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.feature.QuantileDiscretizerPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(QuantileDiscretizerPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
