@@ -7,58 +7,6 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
-class VectorNearestNeighborPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.VectorNearestNeighborPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNearestNeighborPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setRadius(self, val):
-        return self._add_param('radius', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setTopN(self, val):
-        return self._add_param('topN', val)
-
-
-class VectorNearestNeighborTrainBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.VectorNearestNeighborTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNearestNeighborTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setTrainType(self, val):
-        return self._add_param('trainType', val)
-
-    def setMetric(self, val):
-        return self._add_param('metric', val)
-
-
 class VectorNormalizeBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorNormalizeBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -364,35 +312,6 @@ class VectorToKvBatchOp(BatchOperator):
         return self._add_param('reservedCols', val)
 
 
-class VectorToTensorBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.VectorToTensorBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToTensorBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setTensorDataType(self, val):
-        return self._add_param('tensorDataType', val)
-
-    def setTensorShape(self, val):
-        return self._add_param('tensorShape', val)
-
-
 class VectorToTripleBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.VectorToTripleBatchOp'
     OP_TYPE = 'FUNCTION'
