@@ -1,39 +1,54 @@
 import os
 import sys
 from threading import RLock
+from typing import Optional, List
 
 from py4j.java_gateway import GatewayParameters, CallbackServerParameters
 from py4j.java_gateway import JavaGateway
 from py4j.java_gateway import launch_gateway
+from py4j.protocol import Py4JNetworkError
 
-from .config import g_config
-from .common.utils.packages import has_pyflink
+from .common.utils.packages import in_ipython
 
-_gateway = None
+_gateway: Optional[JavaGateway] = None
 _lock = RLock()
 
 
-def set_java_gateway(gateway):
+def set_java_gateway(gateway: JavaGateway):
     global _gateway
     global _lock
     with _lock:
         _gateway = gateway
 
 
+def check_java_gateway_alive(gateway: JavaGateway) -> bool:
+    if gateway is None:
+        return False
+    try:
+        gateway.jvm.System.getProperty("java.runtime.name")
+        return True
+    except Exception or Py4JNetworkError:
+        return False
+
+
 def get_java_gateway():
     global _gateway
     global _lock
     with _lock:
+        if not check_java_gateway_alive(_gateway):
+            LocalJvmBridge.inst().close()
+            _gateway = None
         if _gateway is None:
             _gateway = LocalJvmBridge.inst().gateway
     return _gateway
 
 
-def get_java_class(name):
-    return _gateway.jvm.__getattr__(name)
+def get_java_class(name: str):
+    return get_java_gateway().jvm.__getattr__(name)
 
 
-def list_all_jars():
+def list_all_jars() -> List[str]:
+    from .config import g_config
     alink_deps_dir = g_config["alink_deps_dir"]
     flink_home = g_config["flink_home"]
 
@@ -44,10 +59,9 @@ def list_all_jars():
             os.listdir(os.path.join(flink_home, 'lib'))
             if x.endswith('.jar')]
 
-    if has_pyflink():
-        ret += [os.path.join(flink_home, 'opt', x) for x in
-                os.listdir(os.path.join(flink_home, 'opt'))
-                if x.endswith('.jar') and x.startswith("flink-python")]
+    ret += [os.path.join(flink_home, 'opt', x)
+            for x in os.listdir(os.path.join(flink_home, 'opt'))
+            if x.endswith('.jar') and x.startswith("flink-python")]
     return ret
 
 
@@ -69,16 +83,27 @@ class LocalJvmBridge(object):
         return cls._bridge
 
     def init(self):
+        from .config import g_config
         debug_mode = g_config["debug_mode"]
-        redirect_stdout = sys.stdout if debug_mode else None
-        redirect_stderr = sys.stderr if debug_mode else None
+
+        # always redirect stdout, and only redirect stderr in debug_mode and not in IPython (will fail)
+        redirect_stderr = sys.stderr if debug_mode and not in_ipython() else None
+
+        try:
+            from pyflink.pyflink_gateway_server import construct_log_settings
+            if os.name != 'nt':
+                log_settings = construct_log_settings()
+            else:
+                log_settings = []
+        except ImportError:
+            log_settings = []
 
         if g_config['gateway_port'] is not None:
             self.port = int(g_config['gateway_port'])
         else:
             self.port = launch_gateway(
-                port=0, javaopts=[], die_on_exit=True, daemonize_redirect=True,
-                redirect_stderr=redirect_stdout, redirect_stdout=redirect_stderr,
+                port=0, javaopts=[*log_settings], die_on_exit=True, daemonize_redirect=True,
+                redirect_stdout=sys.stdout, redirect_stderr=redirect_stderr,
                 classpath=os.pathsep.join(list_all_jars()))
         print('JVM listening on 127.0.0.1:{}'.format(self.port))
         self.gateway = JavaGateway(
@@ -93,3 +118,4 @@ class LocalJvmBridge(object):
 
     def close(self):
         self.gateway.close(keep_callback_server=True)
+        self._bridge = None
